"""A dummy module for testing purposes."""
import pytz
import lz4
import numpy


def testfunction():
    return "testfunction"
